@@ -285,6 +285,9 @@ exports.AddDeviceColumn = function(id, options) {
     if ('width' in options)
         coldef.width = options.width;
 
+    if ('sClass' in options)
+        coldef.sClass = options.sClass;
+
     var f;
     if (typeof(coldef.field) === 'string') {
         var fs = coldef.field.split("/");
@@ -528,7 +531,7 @@ exports.AddDetail = function(container, id, title, pos, options) {
 
 exports.DetailWindow = function(key, title, options, window_cb, close_cb) {
     // Generate a unique ID for this dialog
-    var dialogid = "detailialog" + key;
+    var dialogid = "detaildialog" + key;
     var dialogmatch = '#' + dialogid;
 
     if (jsPanel.activePanels.list.indexOf(dialogid) != -1) {
@@ -744,6 +747,8 @@ exports.DeviceDetailWindow = function(key) {
             };
 
             panel.updater();
+
+            new ClipboardJS('.copyuri');
         },
 
         function(panel, options) {
@@ -941,7 +946,7 @@ exports.renderSpeed = function(kph, precision = 5) {
 }
 
 exports.renderTemperature = function(c, precision = 5) {
-    if (kismet.getStorage('kismet.base.unit.temp') === 'celcius' ||
+    if (kismet.getStorage('kismet.base.unit.temp') === 'celsius' ||
             kismet.getStorage('kismet.base.unit.temp') === '') {
         return c.toFixed(precision) + '&deg; C';
     } else {
@@ -1039,6 +1044,7 @@ exports.InitializeDeviceTable = function(element) {
 
         scrollResize: true,
         scrollY: 200,
+        scrollX: "100%",
 
         serverSide: true,
         processing: true,
@@ -1073,6 +1079,10 @@ exports.InitializeDeviceTable = function(element) {
         // Get our dynamic columns
         columns: cols,
 
+        columnDefs: [
+            { className: "dt_td", targets: "_all" },
+        ],
+
         order:
             [ [ 0, "desc" ] ],
 
